"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deactivate = exports.activate = void 0;
const vscode = require("vscode");
const highlightDecorationTypes = [0.7, 0.5, 0.3, 0.2, 0.1, 0.05, 0.025].map(alpha => vscode.window.createTextEditorDecorationType({
    backgroundColor: `RGB(132, 157, 204, ${alpha})`,
}));
function clearHighlightDecorationTypes(editor) {
    highlightDecorationTypes.map(decoration => editor.setDecorations(decoration, []));
}
var traceabilityIsActive = false;
function activate(context) {
    let juliaExtension = vscode.extensions.getExtension('julialang.language-julia');
    if (juliaExtension === undefined) {
        vscode.window.showInformationMessage("Could not find the Julia extension!");
    }
    else if (juliaExtension.isActive === false) {
        juliaExtension.activate().then(function () { console.log("Julia extension activated"); }, function () { console.log("Julia extension activation failed!"); });
    }
    //vscode.commands.executeCommand("language-julia.startREPL");
    let juliaAPI = juliaExtension?.exports;
    function highlightSourceShapes(editor) {
        const position = editor.selection.active;
        const filePath = editor.document.uri.fsPath;
        clearHighlightDecorationTypes(editor);
        juliaAPI.executeInREPL(`KhepriBase.highlight_source_shapes(raw"${filePath}", ${position.line + 1})`, { showCodeInREPL: false, showResultInREPL: false }).then((res) => { });
    }
    context.subscriptions.push(vscode.commands.registerCommand('vsckhepri.generatingCode', () => {
        juliaAPI.executeInREPL('KhepriBase.select_shape_sources_string()', { showCodeInREPL: false, showResultInREPL: false }).then((res) => {
            const ans = res.all.substring(4, res.all.length - 4);
            const results = JSON.parse(ans);
            const editors = vscode.window.visibleTextEditors;
            results.map((result, i) => {
                if (i < highlightDecorationTypes.length) {
                    const path = result[0];
                    const editor = editors.find(e => e.document.fileName === path);
                    if (editor) {
                        clearHighlightDecorationTypes(editor);
                    }
                }
            });
            results.map((result, i) => {
                if (i < highlightDecorationTypes.length) {
                    const path = result[0];
                    const editor = editors.find(e => e.document.fileName === path);
                    if (editor) {
                        const lineNumber = result[1] - 1; //Julia is one-based
                        const line = editor.document.lineAt(lineNumber);
                        const range = new vscode.Range(line.range.start, line.range.end);
                        editor.setDecorations(highlightDecorationTypes[i], [range]);
                    }
                }
                ;
            });
        });
    }));
    context.subscriptions.push(vscode.commands.registerCommand('vsckhepri.generatedShapes', () => {
        const editor = vscode.window.activeTextEditor;
        if (editor) {
            highlightSourceShapes(editor);
        }
    }));
    vscode.window.onDidChangeTextEditorSelection((event) => {
        if (traceabilityIsActive) {
            highlightSourceShapes(event.textEditor);
        }
    });
    context.subscriptions.push(vscode.commands.registerCommand('vsckhepri.toggleTraceability', () => {
        traceabilityIsActive = !traceabilityIsActive;
        vscode.window.setStatusBarMessage(`Khepri's Traceability is ${traceabilityIsActive ? "on" : "off"}.`, 3000);
        const editor = vscode.window.activeTextEditor;
        if (editor) {
            if (traceabilityIsActive) {
                juliaAPI.executeInREPL(`using KhepriBase`, { showCodeInREPL: false, showResultInREPL: false }).then((res) => {
                    highlightSourceShapes(editor);
                });
            }
            else {
                clearHighlightDecorationTypes(editor);
                juliaAPI.executeInREPL(`KhepriBase.highlight_source_shapes("none", -1)`, { showCodeInREPL: false, showResultInREPL: false }).then((res) => {
                    vscode.window.activeTextEditor = editor;
                });
            }
        }
    }));
}
exports.activate = activate;
function deactivate() {
}
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map